@@ -22,7 +22,7 @@ use Log::Scrubber qw(disable $SCRUBBER scrubber :Carp scrubber_add_scrubber);
 @ISA     = qw(Business::OnlinePayment::HTTPS);
 $me      = 'Business::OnlinePayment::Litle';
 $DEBUG   = 0;
-our $VERSION = '0.952'; # VERSION
+our $VERSION = '0.953'; # VERSION
 
 # PODNAME: Business::OnlinePayment::Litle
 
@@ -351,7 +351,7 @@ sub map_request {
     # make sure the date is in MMYY format
     $content->{'expiration'} =~ s/^(\d{1,2})\D*\d*?(\d{2})$/$1$2/;
 
-    if ( ! defined $content->{'description'} ) { $content->{'description'} = ''; } # shema req
+    if ( ! defined $content->{'description'} ) { $content->{'description'} = ''; } # schema req
     $content->{'description'} =~ s/[^\w\s\*\,\-\'\#\&\.]//g;
 
     # Litle pre 0.934 used token, however BOP likes card_token
@@ -454,7 +454,7 @@ sub map_request {
         descriptor => 'description',
       );
 
-    ## loop through product list and generate linItemData for each
+    ## loop through product list and generate lineItemData for each
     #
     my @products = ();
     if( defined $content->{'products'} && scalar( @{ $content->{'products'} } ) < 100 ){
@@ -1723,25 +1723,24 @@ sub chargeback_update_request {
 }
 
 
+
 1; # End of Business::OnlinePayment::Litle
 
 __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Business::OnlinePayment::Litle - Business::OnlinePayment::Litle - Vantiv (was Litle & Co.) Backend for Business::OnlinePayment
 
 =head1 VERSION
 
-version 0.952
+version 0.953
 
 =head1 SYNOPSIS
 
-This is a plugin for the Business::OnlinePayment interface.  Please refer to that docuementation for general usage, and here for Vantiv specific usage.
+This is a plugin for the Business::OnlinePayment interface.  Please refer to that documentation for general usage, and here for Vantiv specific usage.
 
 In order to use this module, you will need to have an account set up with Vantiv L<http://www.vantiv.com/>
 
@@ -1891,7 +1890,7 @@ Default: Live
 =head2 format_misc_field
 
 A new method not directly supported by BOP.
-Used internally to guarentee that XML data will conform to the Litle spec.
+Used internally to guarantee that XML data will conform to the Litle spec.
   field  - The hash key we are checking against
   maxLen - The maximum length allowed (extra bytes will be truncated)
   minLen - The minimum length allowed
@@ -1955,7 +1954,7 @@ Upload a new file
   case_id     => '001',
   filename    => 'mydoc.pdf',
   filecontent => $binaryPdfData,
-  mimetype    => 'applicatoin/pdf',
+  mimetype    => 'application/pdf',
  );
  $tx->chargeback_upload_support_doc();
 
@@ -2141,12 +2140,6 @@ number as the first parameter and should return the masked version.
 
 =head1 FUNCTIONS
 
-=head1 AUTHORS
-
-Jason Hall, C<< <jayce at lug-nut.com> >>
-
-Jason Terry
-
 =head1 UNIMPLEMENTED
 
 Certain features are not yet implemented (no current personal business need), though the capability of support is there, and the test data for the verification suite is there.
@@ -2158,9 +2151,8 @@ Certain features are not yet implemented (no current personal business need), th
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-business-onlinepayment-litle at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Business-OnlinePayment-Litle>. I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to C<bug-business-onlinepayment-litle at rt.cpan.org>.
+I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 You may also add to the code via github, at L<http://github.com/Jayceh/Business--OnlinePayment--Litle.git>
 
@@ -2172,14 +2164,10 @@ You can find documentation for this module with the perldoc command.
 
 You can also look for information at:
 
-L<http://www.litle.com/>
+L<http://www.vantiv.com/>
 
 =over 4
 
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Business-OnlinePayment-Litle>
-
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/Business-OnlinePayment-Litle>
@@ -2188,32 +2176,12 @@ L<http://annocpan.org/dist/Business-OnlinePayment-Litle>
 
 L<http://cpanratings.perl.org/d/Business-OnlinePayment-Litle>
 
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Business-OnlinePayment-Litle/>
-
 =back
 
-=head1 ACKNOWLEDGEMENTS
+=head1 ACKNOWLEDGMENTS
 
 Heavily based on Jeff Finucane's l<Business::OnlinePayment::IPPay> because it also required dynamically writing XML formatted docs to a gateway.
 
-Contributors
-
-Jason Terry - Co-maintainer
-
-David Bartle - Vantiv tokenization support, custom card scrubbers
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2012 Jason Hall.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
-
 =head1 SEE ALSO
 
 perl(1). L<Business::OnlinePayment>
@@ -2222,71 +2190,35 @@ perl(1). L<Business::OnlinePayment>
 
 Jason Hall <jayce@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2015 by Jason Hall.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
-=for stopwords David Bartle Jason Hall (Jayce^) Terry jayce root
+=for stopwords Daina Pettit David Bartle Jason (Jayce^) Hall Terry
 
 =over 4
 
 =item *
 
+Daina Pettit <dpettit@bluehost.com>
+
+=item *
+
 David Bartle <captindave@gmail.com>
 
 =item *
 
-Jason Hall <jayce@bluehost.com>
-
-=item *
-
-Jason Hall <jayce@wyatt.(none)>
-
-=item *
-
 Jason (Jayce^) Hall <jayce@lug-nut.com>
 
 =item *
 
-Jason Terry <jterry@bluehost.com>
-
-=item *
-
-Jason Terry <jterry@Jasons-MacBook-Pro.local>
-
-=item *
-
-Jason Terry <jterry@jterry-laptop.(none)>
-
-=item *
-
-Jason Terry <jterry@jterry-mac.local>
-
-=item *
-
-Jason Terry <jterry@jterry.(none)>
-
-=item *
-
 Jason Terry <oaxlin@gmail.com>
 
-=item *
-
-jayce <jayce@Raistlin.local>
-
-=item *
-
-root <root@jterry.(none)>
-
 =back
 
-=head1 VERSION
+=head1 COPYRIGHT AND LICENSE
 
-version 0.952
+This software is copyright (c) 2016 by Jason Hall.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
